@@ -7,12 +7,12 @@ use v5.26;
 use warnings;
 use utf8;
 
-use Object::Pad 0.800;
+use Object::Pad 0.807;
 
-package App::sdview::Parser::Man 0.13;
-class App::sdview::Parser::Man
-   :does(App::sdview::Parser)
-   :strict(params);
+package App::sdview::Parser::Man 0.14;
+class App::sdview::Parser::Man :strict(params);
+
+apply App::sdview::Parser;
 
 use Parse::Man::DOM 0.03;
 
